from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Float, Boolean, Directory, String

Gacutil_V0_1_0 = CommandToolBuilder(tool="gacutil", base_command=["gacutil"], inputs=[ToolInput(tag="in_installs_assembly_global", input_type=File(optional=True), prefix="-i", doc=InputDocumentation(doc="[-check_refs] [-package NAME] [-root ROOTDIR] [-gacdir GACDIR]\nInstalls an assembly into the global assembly cache.\n<assembly_path> is the name of the file that contains the       assembly manifest\nExample: -i myDll.dll")), ToolInput(tag="in_il", input_type=File(optional=True), prefix="-il", doc=InputDocumentation(doc="[-check_refs] [-package NAME] [-root ROOTDIR] [-gacdir GACDIR]\nInstalls one or more assemblies into the global assembly cache.\n<assembly_list_file> is the path to a test file containing a list of\nassembly file paths on separate lines.\nExample -il assembly_list.txt\nassembly_list.txt contents:\nassembly1.dll\nassembly2.dll")), ToolInput(tag="in_uninstalls_assembly_global", input_type=Float(optional=True), prefix="-u", doc=InputDocumentation(doc="[-package NAME] [-root ROOTDIR] [-gacdir GACDIR]\nUninstalls an assembly from the global assembly cache.\n<assembly_display_name> is the name of the assembly (partial or\nfully qualified) to remove from the global assembly cache. If a\npartial name is specified all matching assemblies will be uninstalled.\nExample: -u myDll,Version=1.2.1.0")), ToolInput(tag="in_ul", input_type=File(optional=True), prefix="-ul", doc=InputDocumentation(doc="[-package NAME] [-root ROOTDIR] [-gacdir GACDIR]\nUninstalls one or more assemblies from the global assembly cache.\n<assembly_list_file> is the path to a test file containing a list of\nassembly names on separate lines.\nExample -ul assembly_list.txt\nassembly_list.txt contents:\nassembly1,Version=1.0.0.0,Culture=en,PublicKeyToken=0123456789abcdef\nassembly2,Version=2.0.0.0,Culture=en,PublicKeyToken=0123456789abcdef")), ToolInput(tag="in_us", input_type=File(optional=True), prefix="-us", doc=InputDocumentation(doc="[-package NAME] [-root ROOTDIR] [-gacdir GACDIR]\nUninstalls an assembly using the specifed assemblies full name.\n<assembly path> is the path to an assembly. The full assembly name\nis retrieved from the specified assembly if there is an assembly in\nthe GAC with a matching name, it is removed.\nExample: -us myDll.dll")), ToolInput(tag="in_lists_contents_cachewhen", input_type=Boolean(optional=True), prefix="-l", doc=InputDocumentation(doc="[assembly_name] [-root ROOTDIR] [-gacdir GACDIR]\nLists the contents of the global assembly cache.\nWhen the <assembly_name> parameter is specified only matching\nassemblies are listed.")), ToolInput(tag="in_package", input_type=Directory(optional=True), prefix="-package", doc=InputDocumentation(doc="Used to create a directory in prefix/lib/mono with the name NAME, and a\nsymlink is created from NAME/assembly_name to the assembly on the GAC.\nThis is used so developers can reference a set of libraries at once.")), ToolInput(tag="in_gac_dir", input_type=Directory(optional=True), prefix="-gacdir", doc=InputDocumentation(doc="Used to specify the GACs base directory. Once an assembly has been installed\nto a non standard gacdir the MONO_GAC_PREFIX environment variable must be used\nto access the assembly.")), ToolInput(tag="in_root", input_type=Directory(optional=True), prefix="-root", doc=InputDocumentation(doc="Used by developers integrating this with automake tools or packaging tools\nthat require a prefix directory to  be specified. The root represents the\n'libdir' component of a prefix (typically prefix/lib).")), ToolInput(tag="in_check_refs", input_type=Boolean(optional=True), prefix="-check_refs", doc=InputDocumentation(doc="Used to ensure that the assembly being installed into the GAC does not\nreference any non strong named assemblies. Assemblies being installed to\nthe GAC should not reference non strong named assemblies, however the is\nan optional check.")), ToolInput(tag="in_mono_gacutil_ignores", input_type=Boolean(optional=True), prefix="-f", doc=InputDocumentation(doc="The Mono gacutil ignores the -f option to maintain commandline compatibility with\nother gacutils. gacutil will always force the installation of a new assembly.")), ToolInput(tag="in_referenceid_descriptionthe_mono", input_type=String(optional=True), prefix="-r", doc=InputDocumentation(doc="<reference_id> <description>\nThe Mono gacutil has not implemented traced references and will emit a warning\nwhen this option is used.\n")), ToolInput(tag="in_commands", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_options", input_type=String(optional=True), position=1, doc=InputDocumentation(doc=""))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Gacutil_V0_1_0().translate("wdl", allow_empty_container=True)

